<template>
  <div>
    <el-dialog
      :title="`${title}关联合同`"
      :visible="visible"
      v-if="visible"
      width="30%"
      top="8vh"
      height="550px"
      :before-close="handleClose"
    >
      <div class="bbsl-common-page">
        <div class="bbsl-table-content" style="height:100%;padding:0;margin:0">
          <el-row :gutter="24">
            <el-col :span="24">
              <el-table
                :row-key="getRowKey"
                ref="multipleTable"
                :data="
                  tableData.filter(
                    data =>
                      !search ||
                      data.contractName
                        .toLowerCase()
                        .includes(search.toLowerCase())
                  )
                "
                @selection-change="handleSelectionChange"
                height="550px"
              >
                <el-table-column
                  type="selection"
                  :reserve-selection="true"
                  width="55"
                >
                </el-table-column>
                <el-table-column label="请选择合同" prop="contractName">
                  <template #default="scope">
                    <div>
                      {{ scope.row.contractName }}（{{
                      scope.row.contractCode
                      }}）
                    </div>
                  </template>
                </el-table-column>
                <el-table-column align="right">
                  <template slot="header">
                    <el-input
                      v-model="search"
                      size="mini"
                      clearable
                      placeholder="输入关键字搜索"
                    />
                  </template>
                </el-table-column>
              </el-table>
            </el-col>
          </el-row>
        </div>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="goInfo">关 联</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import equipmentManage from '@/api/device/equipmentManage.js'
import utils from '@/hotent-ui-util.js'
import {TableMixin} from '@/mixins/tableMixin'
import contractManage from '@/api/device/contractManage.js'

export default {
  name: 'relatedDeviceDialog',
  components: {},
  mixins: [TableMixin],
  data() {
    return {
      visible: false,
      title: '新增',
      relationList: {
        deviceId: '',
        contracts: []
      },
      loading: false,
      multipleSelection: [], // 复选框
      multipleSelection1: [], // 复选框
      tableData: [],
      data: [],
      search: '',
      search1: '',
      tableData1: []
    }
  },
  created() {
    this.loadData()
  },
  methods: {
    add(row) {
      this.visible = true
      this.relationList.deviceId = row.id
      let params = {
        deviceId: row.id
      }
      equipmentManage.getContractList(params, res => {
        this.multipleSelection = res.value.contracts
        if (this.multipleSelection.length) {
          this.$nextTick(() => {
            this.multipleSelection.forEach(item => {
              this.tableData.forEach(val => {
                if (item.id == val.id) {
                  this.$refs.multipleTable.toggleRowSelection(val)
                }
              })
            })
          })
        }
      })
    },
    edit(row) {
    },
    loadData() {
      let data = {
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true
        },
        params: {}
      }
      contractManage.contractQuery(data).then(res => {
        this.loading = true
        this.tableData = res.rows
      })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    filterNode(value, data) {
      if (!value) return true
      return data.name.indexOf(value) !== -1
    },
    // // 指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id
    },
    // 保存
    goInfo() {
      this.relationList.contracts = this.multipleSelection
      let methods
      if (this.title == '新增') {
        methods = equipmentManage.saveDevice
        methods(this.relationList, res => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '关联成功',
              duration: 2000
            })
            this.handleClose()
            this.$parent.loadData()
          }
        })
      }
    },
    getRowKey(row) {
      return row.id
    },
    handleClose() {
      this.$refs.multipleTable.clearSelection()
      this.search = ''
      this.title = '新增'
      this.visible = false
    }
  }
}
</script>
<style lang="scss" scoped>
.el-transfer-panel {
  height: 100% !important;
  width: 100% !important;
}

::v-deep .el-dialog__body {
  padding: 0px;
  height: 600px !important;
  overflow-y: auto !important;
  overflow-x: hidden;
}

::v-deep .el-table::before {
  height: 0;
}

.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}

.el-select-dropdown__item {
  color: #9a9a9a !important;
}

.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}

.el-card__body {
  width: 100% !important;
  height: 100% !important;
}

.custom-tree-node {
  box-sizing: border-box;
  display: flex;
  justify-content: space-around !important;
}

.el-card {
  width: 100% !important;
  height: 100% !important;
}

.el-main {
  width: 100% !important;
  height: 100% !important;
}

.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}

::-webkit-scrollbar {
  background: #fff !important;
}

.custom-tree-node {
  font-size: 12px;
}

.el-popover {
  min-width: 35px !important;
  padding: 5px 0 !important;
}

.line {
  display: block !important;
  height: 1px !important;
  background: #ccc !important;
}

.checkbox-group {
  height: 454px !important;
}
</style>
